## 
## NOTES
## 
## Leaving gtsummary as this is slow and a little inflexible.
## 

## =============================================================================
## Requirements
## =============================================================================

source("function_trans_cols.R")

if (trans_vars==TRUE){
  # If trans_vars flag is TRUE, transform specified variables
  dta<-trans_cols(dta_backup,sqrts=sqrt_vars,log1ps = log1p_vars_all)
} else {dta<-dta_backup}

library(dplyr)
library(gtsummary)

source("function_back_trans.R")

## =============================================================================
## Loop
## =============================================================================

dec <- 3
bm_list<-list()

if (biv_mul){
  do_biv=TRUE
  do_mul=TRUE
} else {
  do_biv=FALSE
  do_mul=TRUE
}

for (i in 1:length(outs)){

  if (!is.null(strat_var)){
    ls<-split(dta,dta[strat_var])
    strat_list<-list()
    
    for (j in 1:length(ls)){
      X<-ls[[j]][,vars] # Choosing the dataset for the given strata and stated variables
      y <- ls[[j]][,outs[i]] # Choosing the outcome data for the given strata and the current outcome variable
      
      # Flagging factors and continous variables
      # 
      sel_f<-X|>
        sapply(is.factor)
      f.names <- colnames(X)[sel_f]
      
      source("function_reg_table.R")
      rt<-reg_table(X,y,m.biv=do_biv,m.mul=do_mul,trans.var = trans_vars,sqrt.vars=sqrt_vars,inter.add=inter_reg)
      
      rt<-rt|>mutate(across(matches('co|lo|hi|pv'),as.numeric))
      
      rt[,grepl('co|lo|hi|pv',names(rt))] <- sapply( round( rt[,grepl('co|lo|hi|pv',names(rt))], 3 ),formatC, format='f', digits=3 )
      
      # Saving the data.frame in indexed list
      strat_list[[j]] <- rt
      
      # Using just the first four characters for shorter colnames in "do.call" later.
      names(strat_list)[j] <- paste0(substr(strat_var,1,4), 
                                     ".",
                                     levels(dta[,strat_var])[j])
      
    }
    
    bm_list[[i]] <- do.call(cbind, strat_list) # cbinds all elements in list, independent of number of strata
    names(bm_list)[i] <- outs[i]
    
  } else {
    X<-dta[,vars]
    y <- dta[,outs[i]]
    
    # Flagging factors and continous variables
    # 
    sel_f<-X|>
      sapply(is.factor)
    f.names <- colnames(X)[sel_f]
    
    source("function_reg_table.R")
    rt<-reg_table(X,y,m.biv=do_biv,m.mul=do_mul,trans.var = trans_vars,sqrt.vars=sqrt_vars,inter.add=inter_reg)
    
    rt<-rt|>mutate(across(matches('co|lo|hi|pv'),as.numeric))
    
    rt[,grepl('co|lo|hi|pv',names(rt))] <- sapply( round( rt[,grepl('co|lo|hi|pv',names(rt))], 3 ),formatC, format='f', digits=3 )
    
    bm_list[[i]] <- rt
    names(bm_list)[i] <- outs[i]
    
  }
  
  }
## =============================================================================
## Print
## =============================================================================

# File name depending onstratification, transformation and back transformation
if (print_tbl==TRUE){
  fnm<-paste0("bm_16_tbl",lbl_x)
  if (!is.null(strat_var)){fnm<-paste0(fnm,"_strat")}
  if (trans_vars==TRUE){fnm<-paste0(fnm,"_trans")}
  # if (trans_back==TRUE){fnm<-paste0(fnm,"_back")}
  
  export<-data.frame()
  for (i in 1:length(bm_list)){
    export<-rbind(export,paste(names(bm_list)[i]),bm_list[[i]])
  }
  
  write.csv(export,paste0(fnm,".csv"))
  
}



