
library(REDCapR)
library(gtsummary)
theme_gtsummary_compact()
library(REDCapR)
library(gt)

library(lubridate)
library(dplyr)
library(tidyr)


dta_all<-read.csv("/Volumes/Data 1/depression/dep_dataset.csv")


# Defining patients to include for analysis
# Only including cases with complete pase_0 and MDI at 1 & 6 months

dta<-dta_all[!is.na(dta_all$pase_0),]
# &!is.na(dta$mdi_1)&!is.na(dta$mdi_6)


## Formatting
dta$diabetes<-factor(dta$diabetes)
dta$pad<-factor(dta$pad)

dta$cohab<-ifelse(dta$civil=="partner","yes","no")|>
  factor()

dta$hypertension<-factor(dta$hypertension)

dta$afli[dta$afli=="unknown"]<-NA
dta$afli<-factor(dta$afli)

dta$ever_smoker<-ifelse(dta$smoke_ever=="ever","yes","no")|>
  factor()

dta$ami<-factor(dta$ami)
dta$tci<-factor(dta$tci)
dta$thrombolysis<-factor(dta$thrombolysis)
dta$thrombechtomy<-factor(dta$thrombechtomy)

dta$any_reperf<-ifelse(dta$rep_any=="rep","yes","no")|>
  factor()

dta$pad<-factor(dta$pad)
dta$nihss_0<-as.numeric(dta$nihss_0)
dta$age<-as.numeric(dta$age)

dta$active_treat<-ifelse(dta$rtreat=="Active","yes","no")|>
  factor()
# dta$rtreat<-factor(dta$rtreat)

dta$female<-ifelse(dta$sex=="female","yes","no")|>
  factor()

dta$pase_0<-as.numeric(dta$pase_0)
dta$pase_6<-as.numeric(dta$pase_6)
dta$bmi<-as.numeric(dta$bmi)
dta$mdi_6<-as.numeric(dta$mdi_6)
dta$pase_0_bin<-factor(dta$pase_0_bin,levels=c("lower","higher"))

dta$nihss_0_isna<-is.na(dta$nihss_0)

dta$pase_0_q<-factor(dta$pase_0_q)

vars<-c("pase_0_q",
        "female",
        "age",
        "cohab",
        "ever_smoker",
        "diabetes", 
        "hypertension", 
        "afli", 
        "ami", 
        "tci",
        "pad",
        "nihss_0",
        "any_reperf",
        "active_treat")

# tbl1_vars<-c("thrombolysis", "thrombechtomy","inc_time")

labels_all<-list(active_treat~"Active trial treatment",
                 pase_0_q~"PASE score quartile",
                 pase_0~"PASE score",
                 age~"Age",
                 female~"Female sex",
                 ever_smoker~"History of smoking",
                 cohab~"Cohabitation",
                 diabetes~"Known diabetes", 
                 hypertension~"Known hypertension", 
                 afli~"Known Atrialfibrillation", 
                 ami~"Previos myocardial infarction", 
                 tci~"Previos TIA",
                 pad~"Known peripheral artery disease",
                 nihss_0~"NIHSS score", 
                 thrombolysis~"Thrombolytic therapy", 
                 thrombechtomy~"Endovascular treatment",
                 any_reperf~"Any reperfusion treatment",
                 inc_time~"Study inclusion time",
                 '[Intercept]'~"Intercept")

lab_sel<-function(label_list,variables_vector){
  ## Helper function to select labels for gtsummary function from list of all labels based on selected variables.
  ## Long names in try to ease reading.
  include_index<-c()
  for (i in 1:length(label_list)) {
    include_index[i]<-as.character(label_list[[i]])[2] %in% variables_vector
  }  
  return(label_list[include_index])
}

dta_backup<-dta
